/* round-volume-frames.m (2024-01-01)

This script only differs from volume-frames.m in the id’s of the animated layer
and the seek map. */

// Never forget to include std.mi:
#include "lib/std.mi"

// Script variables used throughout this script:
Global AnimatedLayer VolumeAnim;
Global Map VolumeMap;
Global GuiObject SongTicker;
Global Text InfoTicker;
Global Timer TickerTimer;
Global Boolean VolumeChanging;

// Functions:
Function setVolumeAnim(int volValue);
Function updateVolume(int x, int y);

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the xml group calling this script:
  Group ScriptGrp = getScriptGroup();

  // Find the xml objects within the group:
  VolumeAnim = ScriptGrp.findObject("Round Volume Frames");
  SongTicker = ScriptGrp.findObject("SongTicker");
  InfoTicker = ScriptGrp.findObject("Infoticker");

  SongTicker.show();
  InfoTicker.hide();

  // Initialize the script’s timer:
  TickerTimer = new Timer;
  TickerTimer.setDelay(750);

  // Load the gradient map:
  VolumeMap = new Map;
  VolumeMap.loadMap("round.volume.map");

  // Send volume level to the setVolumeAnim function:
  setVolumeAnim(System.getVolume());
}

// Do this when the volume changes:
System.onVolumeChanged(int newVol) {
  // Send volume level to the setVolumeAnim function:
  setVolumeAnim(newVol);
  // Calculate percentage:
  int p = (newVol * 100) / 255;
  // Show volume level in the info ticker:
  TickerTimer.start();
  SongTicker.hide();
  InfoTicker.show();
  InfoTicker.setText("Volume: " + System.integerToString(p) + "%");
}

// Show the frame corresponding the volume level:
setVolumeAnim(int Value) {
  int f = (Value * (VolumeAnim.getLength()-1)) / 255;
  if (Value > 0) {
    VolumeAnim.gotoFrame(f+1);
  }
  if (Value == 255) {
    VolumeAnim.gotoFrame(f);
  }
  if (Value == 0) {
    VolumeAnim.gotoFrame(0);
  }
}

// Tell updateVolume that the mouse is pressed and update the animation:
VolumeAnim.onLeftButtonDown(int x, int y) {
  VolumeChanging = 1;
  updateVolume(x, y);
}

// Tell updateVolume that the mouse is released and update the animation:
VolumeAnim.onLeftButtonUp(int x, int y) {
  if (VolumeChanging) {
    VolumeChanging = 0;
    updateVolume(x, y);
  }
}

// Do this when changing the volume with the mouse:
VolumeAnim.onMouseMove(int x, int y) {
  if (VolumeChanging) {
    updateVolume(x, y);
  }
}

// Update the animation:
updateVolume(int x, int y) {
  int newValue = VolumeMap.getValue(x - VolumeAnim.getLeft(), y - VolumeAnim.getTop());
  System.setVolume(newValue);
}

// Show the song ticker again:
TickerTimer.onTimer() {
  SongTicker.show();
  InfoTicker.hide();
  TickerTimer.stop();
}

// Do this before the script is unloaded:
System.onScriptUnloading() {
  delete TickerTimer;
  delete VolumeMap;
}
