/* seek-info.m (2024-01-02)

Show the InfoTicker in place of the SongTicker while dragging the seek slider.

Code extracted from Winamp Modern’s seek.m and comments added by
Ariszló <ariszlo@gmail.com>

Call this script somewhere after the following xml tags (replace the question
marks in the below examples with actual values):

  <Text
    id="InfoTicker"
    x="?" y="?" w="?" h="?"
    visible="0"
  />
  <SongTicker
    id="SongTicker"
    x="?" y="?" w="?" h="?"
  />

Call the script like this:

  <script id="seek-info" file="scripts/seek-info.maki"/> 
*/

// Never forget to include std.mi:
#include "lib/std.mi"

// Script variables used throughout this script:
Global Slider Seeker;
Global GuiObject SongTicker;
Global Text InfoTicker;
Global Timer TickerTimer;
Global Int Seeking;

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the xml group calling this script:
  Group ScriptGrp = getScriptGroup();

  // Find the xml objects within the group:
  Seeker = ScriptGrp.findObject("Seeker");
  SongTicker = ScriptGrp.findObject("SongTicker");
  InfoTicker = ScriptGrp.findObject("InfoTicker");

  SongTicker.show();
  InfoTicker.hide();

  // Initialize the script’s timer:
  TickerTimer = new Timer;
  TickerTimer.setDelay(1000);
}

// Show the song ticker while the timer is running:
TickerTimer.onTimer() {
  SongTicker.show();
  InfoTicker.hide();
  TickerTimer.stop();
}

// Tell the Seeker.onSetPosition function that the slider thumb is dragged:
Seeker.onLeftButtonDown(int x, int y) {
  Seeking = 1;
}

// Tell the Seeker.onSetPosition function that the slider thumb is released
// and show the song ticker again:
Seeker.onLeftButtonUp(int x, int y) {
  Seeking = 0;
  TickerTimer.start();
  SongTicker.show();
  InfoTicker.hide();
}

// The seek bar is divided into 255 segments.
// This function uses a numeric variable (named per255age here) for the segment
// the mouse button is pressed over.
Seeker.onSetPosition(int per255age) {
  if (Seeking) {
    // Introduce a local integer variable named seekage:
    Int seekage;
    // Assign the value of per255age to the newly introduced variable:
    seekage = per255age;

    // getPlayItemLength gets the length of the song in milliseconds.
    // Add a conditional to avoid division by zero:
    if (getPlayItemLength() > 0) {
      // Introduce a local float variable to calculate elapsed time in ms.
      // Float variables are numeric variables with decimals.
      // Local variables are only used within single function,
      // not throughout the whole script.
      Float floatElapsed = getPlayItemLength() * seekage/255;

      // Calculate seek percentage:
      String seekPercentage;
      seekPercentage = integerToString(seekage*100/255);

      // Hide the song ticker and show the info ticker while seeking:
      TickerTimer.start();
      SongTicker.hide();
      InfoTicker.show();

      // For songs shorter than 1 hour, display the current position
      // and the song’s length in MM:SS format: 
      if (getPlayItemLength() < 3600000) {
        InfoTicker.setText(integerToTime(floatElapsed) + " / " + integerToTime(getPlayItemLength()) + "   " + seekPercentage + "%");
      }
      // For songs longer than 1 hour, display the current position
      // and the song’s length in HH:MM:SS format: 
      else {
        InfoTicker.setText(integerToLongTime(floatElapsed) + " / " + integerToLongTime(getPlayItemLength()) + "  " + seekPercentage + "%");
      }
    }
  }
}

// Show the song ticker again:
Seeker.onSetFinalPosition(int p) {
  TickerTimer.start();
  SongTicker.show();
  InfoTicker.hide();
}

// Do this before the script is unloaded:
System.onScriptUnloading() {
  delete TickerTimer;
}
