/* toggle-mute-single-layout.m by Ariszló <ariszlo@gmail.com> (2024-02-27)

A mute-unmute script for a single layout.

Define the bitmaps for the six states of your mute button with following id’s:

  sound.on
  sound.on.hover
  sound.on.pressed
  sound.off
  sound.off.hover
  sound.off.pressed

Define your mute button like this:

  <togglebutton
    id="mute"
    x="?" y="?"
    image="sound.on"
    hoverImage="sound.on.hover"
    downImage="sound.on.pressed"
    activeImage="sound.off"
    tooltip="Click to mute"
    rectrgn="1"
  />

Then add the following tag after it:

  <script id="toggle-mute" file="scripts/toggle-mute-single-layout.maki"/>
*/

#include "lib/std.mi"

// List your *global* variables used throughout this script:
Global Togglebutton muteBtn;
Global Float VolumeLevel;
Global Boolean Muted, BtnPressed;

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the xml group containing the tag calling this script:
  Group ScriptGroup = getScriptGroup();

  // Find the mute button within the group:
  muteBtn = ScriptGroup.findObject("mute");

  // Get last saved muted/unmuted state.
  // If no state is saved then take it as unmuted:
  Muted = getPrivateInt("winamp5", "muted", 0);
  // Get the volume level saved before muting:
  VolumeLevel = getPrivateInt("winamp5", "old_volume", 0);

  if (Muted) {
    muteBtn.setActivated(1);
    // Match hoverImage and downImage with activeImage:
    muteBtn.setXmlParam("hoverImage", "sound.off.hover");
    muteBtn.setXmlParam("downImage", "sound.off.pressed");
    // Replace tooltip text with this:
    muteBtn.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    muteBtn.setActivated(0);
    // Match hoverImage and downImage with Image:
    muteBtn.setXmlParam("hoverImage", "sound.on.hover");
    muteBtn.setXmlParam("downImage", "sound.on.pressed");
    // Restore tooltip text:
    muteBtn.setXmlParam("tooltip", "Click to mute");
  }

  BtnPressed = 0;
}

muteBtn.onLeftClick() {
  BtnPressed = 1;
  if (!Muted) {
    VolumeLevel = System.getVolume();
    System.setVolume(0);
    Muted = 1;
    muteBtn.setXmlParam("hoverImage", "sound.off.hover");
    muteBtn.setXmlParam("downImage", "sound.off.pressed");
    muteBtn.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    System.setVolume(VolumeLevel);
    Muted = 0;
    muteBtn.setXmlParam("hoverImage", "sound.on.hover");
    muteBtn.setXmlParam("downImage", "sound.on.pressed");
    muteBtn.setXmlParam("tooltip", "Click to mute");
  }
}

System.onvolumechanged(int newvol) {
  if (!BtnPressed) {
    if (Muted) {
      muteBtn.setActivated(0);
      Muted = 0;
      muteBtn.setXmlParam("hoverImage", "sound.on.hover");
      muteBtn.setXmlParam("downImage", "sound.on.pressed");
      muteBtn.setXmlParam("tooltip", "Click to mute");
    }
  }
  BtnPressed = 0;
}

System.onScriptUnloading() {
  setPrivateInt("winamp5", "muted", Muted);
  setPrivateInt("winamp5", "old_volume", VolumeLevel);
}
