/* toggle-mute.m by Ariszló <ariszlo@gmail.com> (2024-02-27)

A mute-unmute script for three layouts.

Define the bitmaps for the six states of your mute button with following id’s:

  sound.on
  sound.on.hover
  sound.on.pressed
  sound.off
  sound.off.hover
  sound.off.pressed

Define your mute button like this (replace the question marks with actual values):

  <togglebutton
    id="mute"
    x="?" y="?"
    image="sound.on"
    hoverImage="sound.on.hover"
    downImage="sound.on.pressed"
    activeImage="sound.off"
    tooltip="Click to mute"
    rectrgn="1"
  />

Call this script after the include tags in player.xml or skin.xml like this:

  <script id="toggle-mute" file="scripts/toggle-mute.maki"/>
*/

#include "lib/std.mi"

// List your *global* variables used throughout this script:
Global Container main;
Global Layout mainOne, mainTwo, mainThree;
Global Togglebutton muteOne, muteTwo, muteThree;
Global Float VolumeLevel;
Global Boolean Muted, BtnPressed;

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the main window:
  main = getContainer("main");

  // Get the layouts with the mute buttons.
  // Make sure the quoted strings match the id’s of your main window layouts:
  mainOne = main.getLayout("normal");
  mainTwo = main.getLayout("frames");
  mainThree = main.getLayout("regions");

  // Make sure the quoted strings match the id’s of your toggle buttons:
  muteOne = mainOne.findObject("mute");
  muteTwo = mainTwo.findObject("mute");
  muteThree = mainThree.findObject("mute");

  // Get last saved muted/unmuted state.
  // If no state is saved then take it as unmuted:
  Muted = getPrivateInt("winamp5", "muted", 0);
  // Get the volume level saved before muting:
  VolumeLevel = getPrivateInt("winamp5", "old_volume", 0);

  if (Muted) {
    muteOne.setActivated(1);
    muteTwo.setActivated(1);
    muteThree.setActivated(1);

    muteOne.setXmlParam("hoverImage", "sound.off.hover");
    muteOne.setXmlParam("downImage", "sound.off.pressed");
    muteOne.setXmlParam("tooltip", "Click to unmute");

    muteTwo.setXmlParam("hoverImage", "sound.off.hover");
    muteTwo.setXmlParam("downImage", "sound.off.pressed");
    muteTwo.setXmlParam("tooltip", "Click to unmute");

    muteThree.setXmlParam("hoverImage", "sound.off.hover");
    muteThree.setXmlParam("downImage", "sound.off.pressed");
    muteThree.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    muteOne.setActivated(0);
    muteTwo.setActivated(0);
    muteThree.setActivated(0);

    muteOne.setXmlParam("hoverImage", "sound.on.hover");
    muteOne.setXmlParam("downImage", "sound.on.pressed");
    muteOne.setXmlParam("tooltip", "Click to mute");

    muteTwo.setXmlParam("hoverImage", "sound.on.hover");
    muteTwo.setXmlParam("downImage", "sound.on.pressed");
    muteTwo.setXmlParam("tooltip", "Click to mute");

    muteThree.setXmlParam("hoverImage", "sound.on.hover");
    muteThree.setXmlParam("downImage", "sound.on.pressed");
    muteThree.setXmlParam("tooltip", "Click to mute");
  }

  BtnPressed = 0;
}

muteOne.onLeftClick() {
  BtnPressed = 1;
  if (!Muted) {
    VolumeLevel = System.getVolume();
    System.setVolume(0);
    Muted = 1;
    muteTwo.setActivated(1);
    muteThree.setActivated(1);

    muteOne.setXmlParam("hoverImage", "sound.off.hover");
    muteOne.setXmlParam("downImage", "sound.off.pressed");
    muteOne.setXmlParam("tooltip", "Click to unmute");

    muteTwo.setXmlParam("hoverImage", "sound.off.hover");
    muteTwo.setXmlParam("downImage", "sound.off.pressed");
    muteTwo.setXmlParam("tooltip", "Click to unmute");

    muteThree.setXmlParam("hoverImage", "sound.off.hover");
    muteThree.setXmlParam("downImage", "sound.off.pressed");
    muteThree.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    System.setVolume(VolumeLevel);
    Muted = 0;
    muteTwo.setActivated(0);
    muteThree.setActivated(0);

    muteOne.setXmlParam("hoverImage", "sound.on.hover");
    muteOne.setXmlParam("downImage", "sound.on.pressed");
    muteOne.setXmlParam("tooltip", "Click to mute");

    muteTwo.setXmlParam("hoverImage", "sound.on.hover");
    muteTwo.setXmlParam("downImage", "sound.on.pressed");
    muteTwo.setXmlParam("tooltip", "Click to mute");

    muteThree.setXmlParam("hoverImage", "sound.on.hover");
    muteThree.setXmlParam("downImage", "sound.on.pressed");
    muteThree.setXmlParam("tooltip", "Click to mute");
  }
}

muteTwo.onLeftClick() {
  BtnPressed = 1;
  if (!Muted) {
    VolumeLevel = System.getVolume();
    System.setVolume(0);
    Muted = 1;
    muteOne.setActivated(1);
    muteThree.setActivated(1);

    muteOne.setXmlParam("hoverImage", "sound.off.hover");
    muteOne.setXmlParam("downImage", "sound.off.pressed");
    muteOne.setXmlParam("tooltip", "Click to unmute");

    muteTwo.setXmlParam("hoverImage", "sound.off.hover");
    muteTwo.setXmlParam("downImage", "sound.off.pressed");
    muteTwo.setXmlParam("tooltip", "Click to unmute");

    muteThree.setXmlParam("hoverImage", "sound.off.hover");
    muteThree.setXmlParam("downImage", "sound.off.pressed");
    muteThree.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    System.setVolume(VolumeLevel);
    Muted = 0;
    muteOne.setActivated(0);
    muteThree.setActivated(0);

    muteOne.setXmlParam("hoverImage", "sound.on.hover");
    muteOne.setXmlParam("downImage", "sound.on.pressed");
    muteOne.setXmlParam("tooltip", "Click to mute");

    muteTwo.setXmlParam("hoverImage", "sound.on.hover");
    muteTwo.setXmlParam("downImage", "sound.on.pressed");
    muteTwo.setXmlParam("tooltip", "Click to mute");

    muteThree.setXmlParam("hoverImage", "sound.on.hover");
    muteThree.setXmlParam("downImage", "sound.on.pressed");
    muteThree.setXmlParam("tooltip", "Click to mute");
  }
}

muteThree.onLeftClick() {
  BtnPressed = 1;
  if (!Muted) {
    VolumeLevel = System.getVolume();
    System.setVolume(0);
    Muted = 1;
    muteOne.setActivated(1);
    muteTwo.setActivated(1);

    muteOne.setXmlParam("hoverImage", "sound.off.hover");
    muteOne.setXmlParam("downImage", "sound.off.pressed");
    muteOne.setXmlParam("tooltip", "Click to unmute");

    muteTwo.setXmlParam("hoverImage", "sound.off.hover");
    muteTwo.setXmlParam("downImage", "sound.off.pressed");
    muteTwo.setXmlParam("tooltip", "Click to unmute");

    muteThree.setXmlParam("hoverImage", "sound.off.hover");
    muteThree.setXmlParam("downImage", "sound.off.pressed");
    muteThree.setXmlParam("tooltip", "Click to unmute");
  }
  else {
    System.setVolume(VolumeLevel);
    Muted = 0;
    muteOne.setActivated(0);
    muteTwo.setActivated(0);

    muteOne.setXmlParam("hoverImage", "sound.on.hover");
    muteOne.setXmlParam("downImage", "sound.on.pressed");
    muteOne.setXmlParam("tooltip", "Click to mute");

    muteTwo.setXmlParam("hoverImage", "sound.on.hover");
    muteTwo.setXmlParam("downImage", "sound.on.pressed");
    muteTwo.setXmlParam("tooltip", "Click to mute");

    muteThree.setXmlParam("hoverImage", "sound.on.hover");
    muteThree.setXmlParam("downImage", "sound.on.pressed");
    muteThree.setXmlParam("tooltip", "Click to mute");
  }
}

System.onvolumechanged(int newvol) {
  if (!BtnPressed) {
    if (Muted) {
      muteOne.setActivated(0);
      muteTwo.setActivated(0);
      muteThree.setActivated(0);
      Muted = 0;

      muteOne.setXmlParam("hoverImage", "sound.on.hover");
      muteOne.setXmlParam("downImage", "sound.on.pressed");
      muteOne.setXmlParam("tooltip", "Click to mute");

      muteTwo.setXmlParam("hoverImage", "sound.on.hover");
      muteTwo.setXmlParam("downImage", "sound.on.pressed");
      muteTwo.setXmlParam("tooltip", "Click to mute");

      muteThree.setXmlParam("hoverImage", "sound.on.hover");
      muteThree.setXmlParam("downImage", "sound.on.pressed");
      muteThree.setXmlParam("tooltip", "Click to mute");
    }
  }
  BtnPressed = 0;
}

System.onScriptUnloading() {
  setPrivateInt("winamp5", "muted", Muted);
  setPrivateInt("winamp5", "old_volume", VolumeLevel);
}
