/* volume-fill.m by Ariszló <ariszlo@gmail.com> 2024-01-02

Fill a vertical volume bar with a stretchable layer up to the volume thumb.
For a horizontal volume bar, use the much simpler volume-trail script.

Call this script somewhere after the following xml tags (replace the question
marks in the below examples with actual values):

  <Text
    id="InfoTicker"
    x="?" y="?" w="?" h="?"
    visible="0"
  />
  <SongTicker
    id="SongTicker"
    x="?" y="?" w="?" h="?"
  />
  <Layer
    id="Volume Fill"
    x="?" w="?"
    image="?"
  />
  <slider
    id="Volume"
    action="VOLUME"
    x="?" y="?" w="?" h="?"
    thumb="?" downThumb="?"
    orientation="vertical"
  />

Call the script like this:

  <script id="volume-fill" file="scripts/volume-fill.maki"/>
*/

// Never forget to include std.mi:
#include "lib/std.mi"

// Script variables used throughout this script:
Global Slider VolumeSlider;
Global Layer VolumeFill;
Global GuiObject SongTicker;
Global Text InfoTicker;
Global Timer TickerTimer;
Global Int maxHeight, maxTop;

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the xml group calling this script:
  Group ScriptGrp = getScriptGroup();

  // Find the xml objects within the group:
  VolumeSlider = ScriptGrp.getObject("Volume");
  VolumeFill = ScriptGrp.findObject("Volume Fill");
  SongTicker = ScriptGrp.findObject("SongTicker");
  InfoTicker = ScriptGrp.findObject("InfoTicker");

  SongTicker.show();
  InfoTicker.hide();

  // Initialize the script’s timer:
  TickerTimer = new Timer;
  TickerTimer.setDelay(750);

  // Get the height and position of the volume bar:
  maxHeight = StringToInteger(VolumeSlider.getXmlParam("h"));
  maxTop = StringToInteger(VolumeSlider.getXmlParam("y"));

  // Calculate how high to fill the volume bar:
  String loadHeight = integerToString((getVolume()/255) * maxHeight);
  String loadTop = integerToString(maxTop + maxHeight - (getVolume()/255)*maxHeight); 

  // Fill the volume bar up to the slider:
  VolumeFill.setXmlParam("h",loadHeight);
  VolumeFill.setXmlParam("y",loadTop);
}

// Do this when the volume changes:
System.onVolumeChanged(int newvol) {
  // Calculate how high to fill the volume bar:
  String newHeight = integerToString((newvol/255) * maxHeight);
  String newTop = integerToString(maxTop + maxHeight - (newvol/255)*maxHeight); 

  // Fill the volume bar up to the slider:
  VolumeFill.setXmlParam("h",newHeight);
  VolumeFill.setXmlParam("y",newTop);

  // Show the info ticker while volume is changing:
  TickerTimer.start();
  SongTicker.hide();
  InfoTicker.show();
  InfoTicker.setText("Volume" + ": " + integerToString(newvol/2.55) + "%");
}

// Show the song ticker again:
TickerTimer.onTimer() {
  SongTicker.show();
  InfoTicker.hide();
  TickerTimer.stop();
}

// Do this before the script is unloaded:
System.onScriptUnloading() {
  delete TickerTimer;
}
