/* volume-trail.m by Ariszló <ariszlo@gmail.com> 2024-01-02

Show a trail image before the volume thumb in a horizontal volume bar.
For a vertical volume bar, use the more complex volume-fill script.

Call this script somewhere after the following xml tags (replace the question
marks in the below examples with actual values):

  <Text
    id="InfoTicker"
    x="?" y="?" w="?" h="?"
    visible="0"
  />
  <SongTicker
    id="SongTicker"
    x="?" y="?" w="?" h="?"
  />
  <Layer
    id="Volume Trail"
    x="?" w="?"
    image="?"
  />
  <slider
    id="Volume"
    action="VOLUME"
    x="?" y="?" w="?" h="?"
    thumb="?" downThumb="?"
    orientation="horizontal"
  />

Call the script like this:

  <script id="volume-trail" file="scripts/volume-trail.maki"/>
*/

// Never forget to include std.mi:
#include "lib/std.mi"

// Script variables used throughout this script:
Global Slider VolumeSlider;
Global Layer VolumeTrail;
Global GuiObject SongTicker;
Global Text InfoTicker;
Global Timer TickerTimer;
Global Int maxWidth;

// Do this when the script is loaded:
System.onScriptLoaded() {
  // Get the xml group calling this script:
  Group ScriptGrp = getScriptGroup();

  // Find the xml objects within the group:
  VolumeSlider = ScriptGrp.getObject("Volume");
  VolumeTrail = ScriptGrp.findObject("Volume Trail");
  SongTicker = ScriptGrp.findObject("SongTicker");
  InfoTicker = ScriptGrp.findObject("InfoTicker");

  SongTicker.show();
  InfoTicker.hide();

  // Initialize the script’s timer:
  TickerTimer = new Timer;
  TickerTimer.setDelay(750);

  // Get the width of the volume bar:
  maxWidth = stringtointeger(VolumeSlider.getXmlParam("w"));

  // Calculate the length of the trail:
  String loadWidth = integertostring((getVolume()/255) * maxWidth);

  // Set the length of the trail:
  VolumeTrail.setXmlParam("w",loadWidth);
}

// Do this when the volume changes:
System.onvolumechanged(int newvol) {
  // Calculate the length of the trail:
  String newWidth = integertostring((newvol/255) * maxWidth);

  // Set the length of the trail:
  VolumeTrail.setXmlParam("w",newWidth);

  // Show the info ticker while volume is changing:
  TickerTimer.start();
  SongTicker.hide();
  InfoTicker.show();
  InfoTicker.setText("Volume" + ": " + integerToString(newvol/2.55) + "%");
}

// Show the song ticker again:
TickerTimer.onTimer() {
  SongTicker.show();
  InfoTicker.hide();
  TickerTimer.stop();
}

// Do this before the script is unloaded:
System.onScriptUnloading() {
  delete TickerTimer;
}
